"${PREFIX}/bin/glib-compile-schemas" "${PREFIX}/share/glib-2.0/schemas"
"${PREFIX}/bin/gtk-update-icon-cache" -f -t "${PREFIX}/share/icons/hicolor"
"${PREFIX}/bin/gtk-query-immodules-3.0" > "${PREFIX}/lib/gtk-3.0/3.0.0/immodules.cache"
