



gtk-encode-symbolic-svg --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
gtk-launch --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
gtk-query-immodules-3.0
IF %ERRORLEVEL% NEQ 0 exit /B 1
gtk-update-icon-cache --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
where gtk-builder-tool
IF %ERRORLEVEL% NEQ 0 exit /B 1
where gtk-query-settings
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\gail-3.0\\libgail-util\\gail-util.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\gtk-3.0\\gdk\\gdk.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\gtk-3.0\\gdk\\win32\\gdkwin32window.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\gtk-3.0\\gtk\\gtk.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\pkgconfig\\gail-3.0.pc exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\pkgconfig\\gdk-3.0.pc exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\pkgconfig\\gtk+-3.0.pc exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\pkgconfig\\gdk-win32-3.0.pc exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\pkgconfig\\gtk+-win32-3.0.pc exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\bin\\gailutil-3-vs15.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
for /f "usebackq tokens=*" %%a in (`pkg-config --variable=exec_prefix --dont-define-prefix gail-3.0`) do if not exist "%%a/bin/gailutil-3-vs15.dll" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\gailutil-3.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
for /f "usebackq tokens=*" %%a in (`pkg-config --variable=libdir --dont-define-prefix gail-3.0`) do if not exist "%%a/gailutil-3.lib" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\bin\\gdk-3-vs15.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
for /f "usebackq tokens=*" %%a in (`pkg-config --variable=exec_prefix --dont-define-prefix gdk-3.0`) do if not exist "%%a/bin/gdk-3-vs15.dll" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\gdk-3.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
for /f "usebackq tokens=*" %%a in (`pkg-config --variable=libdir --dont-define-prefix gdk-3.0`) do if not exist "%%a/gdk-3.lib" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\bin\\gtk-3-vs15.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
for /f "usebackq tokens=*" %%a in (`pkg-config --variable=exec_prefix --dont-define-prefix gtk+-3.0`) do if not exist "%%a/bin/gtk-3-vs15.dll" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\gtk-3.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
for /f "usebackq tokens=*" %%a in (`pkg-config --variable=libdir --dont-define-prefix gtk+-3.0`) do if not exist "%%a/gtk-3.lib" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
